@@ -19,6 +19,8 @@
 
 #include "gd-header-bar.h"
 
+#include <string.h>
+
 /* TODO
  * - wm communication
  */
@@ -159,7 +161,6 @@ gd_header_bar_get_size (GtkWidget      *widget,
   GList *l;
   gint nvis_children;
   gint minimum, natural;
-  gint padding;
   GtkBorder css_borders;
 
   minimum = natural = 0;
@@ -430,6 +431,13 @@ gd_header_bar_size_allocate (GtkWidget     *widget,
 
   gtk_widget_set_allocation (widget, allocation);
 
+  if (gtk_widget_get_realized (widget))
+    gdk_window_move_resize (priv->event_window,
+                            allocation->x,
+                            allocation->y,
+                            allocation->width,
+                            allocation->height);
+
   direction = gtk_widget_get_direction (widget);
   nvis_children = count_visible_children (bar);
   sizes = g_newa (GtkRequestedSize, nvis_children);
@@ -482,18 +490,25 @@ gd_header_bar_size_allocate (GtkWidget     *widget,
       else
         x = allocation->x + allocation->width - priv->hpadding;
 
-      i = 0;
-      for (l = priv->children; l; l = l->next)
+      if (packing == GTK_PACK_START)
+	{
+	  l = priv->children;
+	  i = 0;
+	}
+      else
+	{
+	  l = g_list_last (priv->children);
+	  i = nvis_children - 1;
+	}
+
+      for (; l != NULL; (packing == GTK_PACK_START) ? (l = l->next) : (l = l->prev))
         {
           child = l->data;
           if (!gtk_widget_get_visible (child->widget))
             continue;
 
           if (child->pack_type != packing)
-            {
-              i++;
-              continue;
-            }
+            goto next;
 
           child_size = sizes[i].minimum_size;
 
@@ -518,7 +533,12 @@ gd_header_bar_size_allocate (GtkWidget     *widget,
             child_allocation.x = allocation->x + allocation->width - (child_allocation.x - allocation->x) - child_allocation.width;
 
           gtk_widget_size_allocate (child->widget, &child_allocation);
-          i++;
+
+        next:
+          if (packing == GTK_PACK_START)
+            i++;
+          else
+            i--;
         }
     }
 
