@@ -19,14 +19,12 @@
  *
  */
 
-const Clutter = imports.gi.Clutter;
 const EvView = imports.gi.EvinceView;
 const Gd = imports.gi.Gd;
 const Gdk = imports.gi.Gdk;
 const GLib = imports.gi.GLib;
 const GObject = imports.gi.GObject;
 const Gtk = imports.gi.Gtk;
-const GtkClutter = imports.gi.GtkClutter;
 const Pango = imports.gi.Pango;
 const _ = imports.gettext.gettext;
 
@@ -37,7 +35,7 @@ const Notifications = imports.notifications;
 const Properties = imports.properties;
 const Query = imports.query;
 const Sharing = imports.sharing;
-const Tweener = imports.util.tweener;
+const Tweener = imports.tweener.tweener;
 const Utils = imports.utils;
 
 const Lang = imports.lang;
@@ -721,30 +719,19 @@ const _SELECTION_TOOLBAR_DEFAULT_WIDTH = 500;
 const SelectionToolbar = new Lang.Class({
     Name: 'SelectionToolbar',
 
-    _init: function(parentActor) {
+    _init: function() {
         this._itemListeners = {};
         this._insideRefresh = false;
-        this._parentActor = parentActor;
 
         this.widget = new Gtk.Toolbar({ show_arrow: false,
-                                        icon_size: Gtk.IconSize.LARGE_TOOLBAR });
+                                        halign: Gtk.Align.CENTER,
+                                        valign: Gtk.Align.END,
+                                        margin_bottom: 40,
+                                        icon_size: Gtk.IconSize.LARGE_TOOLBAR,
+                                        opacity: 0 });
         this.widget.get_style_context().add_class('osd');
         this.widget.set_size_request(_SELECTION_TOOLBAR_DEFAULT_WIDTH, -1);
 
-        this.actor = new GtkClutter.Actor({ contents: this.widget,
-                                            show_on_set_parent: false,
-                                            opacity: 0 });
-        Utils.alphaGtkWidget(this.actor.get_widget());
-
-        this.actor.add_constraint(
-            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.X_AXIS,
-                                          source: this._parentActor,
-                                          factor: 0.50 }));
-        this.actor.add_constraint(
-            new Clutter.AlignConstraint({ align_axis: Clutter.AlignAxis.Y_AXIS,
-                                          source: this._parentActor,
-                                          factor: 0.95 }));
-
         this._leftBox = new Gtk.Box({ orientation: Gtk.Orientation.HORIZONTAL });
         this._leftGroup = new Gtk.ToolItem({ child: this._leftBox });
         this.widget.insert(this._leftGroup, -1);
@@ -948,16 +935,16 @@ const SelectionToolbar = new Lang.Class({
     },
 
    _onToolbarShare: function(widget) {
-	    let dialog = new Sharing.SharingDialog();
-        this._fadeOut();
+       let dialog = new Sharing.SharingDialog();
+       this._fadeOut();
 
-        dialog.widget.connect('response', Lang.bind(this,
-            function(widget, response) {
-                if (response == Gtk.ResponseType.OK) {
-                    dialog.widget.destroy();
-                    this._fadeIn();
-                }
-            }));
+       dialog.widget.connect('response', Lang.bind(this,
+           function(widget, response) {
+               if (response == Gtk.ResponseType.OK) {
+                   dialog.widget.destroy();
+                   this._fadeIn();
+               }
+           }));
     },
 
     _onToolbarPrint: function(widget) {
@@ -971,26 +958,19 @@ const SelectionToolbar = new Lang.Class({
     },
 
     _fadeIn: function() {
-        if (this.actor.opacity != 0)
-            return;
-
-        this.actor.opacity = 0;
-        this.actor.show();
-
-        Tweener.addTween(this.actor,
-            { opacity: 255,
-              time: 0.30,
-              transition: 'easeOutQuad' });
+        this.widget.show();
+        Tweener.addTween(this.widget, { opacity: 1,
+                                        time: 0.30,
+                                        transition: 'easeOutQuad' });
     },
 
     _fadeOut: function() {
-        Tweener.addTween(this.actor,
-            { opacity: 0,
-              time: 0.30,
-              transition: 'easeOutQuad',
-              onComplete: function() {
-                  this.actor.hide();
-              },
-              onCompleteScope: this });
+        Tweener.addTween(this.widget, { opacity: 0,
+                                        time: 0.30,
+                                        transition: 'easeOutQuad',
+                                        onComplete: function() {
+                                            this.widget.hide();
+                                        },
+                                        onCompleteScope: this });
     }
 });
